==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/eu.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Lehenaldilo laguntza",
    "Add your profile information! For example your email is needed to reset your password." : "Gehitu zure informazio-profila! Adibidez, zure posta elektronikoa behar da pasahitza berrezartzeko.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Gehitu zure informazio-profila! Ezarri profileko argazkia eta izena, ezaugarri guztietan aitorpena errazago egiteko.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Gehitu zure informazio-profila! Ezarri izena, ezaugarri guztietan aitorpena errazago egiteko.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Gehitu zure informazio-profila! Ezarri profileko argazkia, ezaugarri guztietan aitorpena errazago egiteko.",
    "Get the apps to sync your files" : "Lortu aplikazioak zure fitxategiak sinkronizatzeko",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Access files via WebDAV" : "Eskuratu fitxategiak WebDAV bidez",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Erabili eta partekatu fitxategiak, egutegiak, kontaktuak, mezuak eta gehiago edozein gailutik",
    "Connect your desktop apps to %s" : "Konektatu zure mahaigaineko aplikazioak %s-era",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Informazio gehiago <a target=\"_blank\" href=\"%s\">dokumentazioan</a> eta gure <a target=\"_blank\" href=\"%s\">webgunean</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!",
    "Connect your Calendar" : "Konektatu zure Egutegia",
    "Connect your Contacts" : "Konektatu zure Kontaktuak"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/eu.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Lehenaldilo laguntza",
    "Add your profile information! For example your email is needed to reset your password." : "Gehitu zure informazio-profila! Adibidez, zure posta elektronikoa behar da pasahitza berrezartzeko.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Gehitu zure informazio-profila! Ezarri profileko argazkia eta izena, ezaugarri guztietan aitorpena errazago egiteko.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Gehitu zure informazio-profila! Ezarri izena, ezaugarri guztietan aitorpena errazago egiteko.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Gehitu zure informazio-profila! Ezarri profileko argazkia, ezaugarri guztietan aitorpena errazago egiteko.",
    "Get the apps to sync your files" : "Lortu aplikazioak zure fitxategiak sinkronizatzeko",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Connect your desktop apps to %s" : "Konektatu zure mahaigaineko aplikazioak %s-era",
    "Access files via WebDAV" : "Eskuratu fitxategiak WebDAV bidez",
    "User manual" : "Erabiltzailearen manuala",
    "Admin manual" : "Administratzailearen manuala",
    "Developer manual" : "Garatzailearen manuala",
    "Previous" : "Aurrekoa",
    "Next" : "Hurrengoa",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Erabili eta partekatu fitxategiak, egutegiak, kontaktuak, mezuak eta gehiago edozein gailutik",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Informazio gehiago <a target=\"_blank\" href=\"%s\">dokumentazioan</a> eta gure <a target=\"_blank\" href=\"%s\">webgunean</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!"
},
"nplurals=2; plural=(n != 1);");
